#!/usr/bin/perl

use LWP::UserAgent;
use Data::Dumper;
use JSON;
use Time::HiRes;

if ( scalar(@ARGV) != 3 ) {
    print "Usage: $0 JazzURI, JazzUser, JazzPass\n";
    exit -1;
}
my ($JazzURI, $JazzUser, $JazzPass) = @ARGV;

    my $Browser = LWP::UserAgent->new;
    $Browser->timeout(15);
    $Browser->cookie_jar({ $JazzURI . "cookie.txt"});
    $Browser->default_header('Accept' => "text/json");
    push @{ $Browser->requests_redirectable }, 'POST';


# Test the connection to CLM
    my ( $BeginTime ) = Time::HiRes::time();
    $Response = $Browser->post( $JazzURI );
    my ( $EndTime ) = Time::HiRes::time();

    if ( ! $Response->is_success )  {
       print "Connecting to $JazzURI FAILED!\n";
       exit -1;
    } else {
       my($printString) = sprintf("%s%.2f%s", "Connection to $JazzURI completed in ", $EndTime - $BeginTime, " Seconds.\n");
       print $printString;
    }


# Test the Authetication to CLM
    my ( $BeginTime ) = Time::HiRes::time();
    $Response = $Browser->post( $JazzURI . "/j_security_check", [ j_username => $JazzUser, j_password => $JazzPass ], );
    my ( $EndTime ) = Time::HiRes::time();

    if ( $Response->{"_headers"}{"x-com-ibm-team-repository-web-auth-msg"} eq "authfailed" )  {
       print "Authenticating to $JazzURI FAILED!\n";
       exit -1;
    } else {
       my($printString) = sprintf("%s%.2f%s", "Authentication to $JazzURI completed in ", $EndTime - $BeginTime, " Seconds.\n");
       print $printString;
    }

# Test the Database connection status to CLM
    my ( $BeginTime ) = Time::HiRes::time();
    $Response = $Browser->get( $JazzURI . "/service/com.ibm.team.repository.service.internal.IServerStatusRestService/databaseStatus");
    my ( $EndTime ) = Time::HiRes::time();

    my($json) = new JSON;
    my($jsonResponse) = $json->decode($Response->content);

    if ( $jsonResponse->{"soapenv:Body"}{response}{returnValue}{value}{code} ne "OK") {
       print "Database Status for CLM Server \@ $JazzURI is not OK!\n";
       print "Database connection Status message provided by CLM is:\n";
       print $jsonResponse->{"soapenv:Body"}{response}{returnValue}{value}{message};
       exit -1;
    } else {
       my($printString) = sprintf("%s%.2f%s","Retrieving Database Status for CLM Server \@ $JazzURI is completed in ", $EndTime - $BeginTime, " Seconds.\n");
       print $printString;
    }

